Welcome to TransformInvariantNMF's documentation!
=================================================
A comprehensive Python package for **Non-Negative Matrix Factorization (NMF)** with a focus on learning *transform-invariant representations*.

The packages supports multiple optimization backends and can be easily extended to handle application-specific types of transforms.


.. toctree::
   :maxdepth: 2
   :caption: Contents

   link_generalintroduction
   autoapi/index
   link_changelog
   link_license
   Installation <https://github.com/emdgroup/tnmf/tree/main#installation>
   Contributing <https://github.com/emdgroup/tnmf/tree/main#contributing>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
